<h6 align="center">
  <img src="https://i.imgur.com/CQ7S8hN.png" alt="Amanobot" height="150px">
  <h2 align="center">Amanobot</h2>
  <h6 align="center">Python framework for Telegram Bot API forked from Telepot</h6>
</h6>
<h6 align="center">
  <a href="https://pypi.org/project/amanobot"><img src="https://img.shields.io/pypi/v/amanobot.svg" /></a>
  <a href="https://core.telegram.org/bots/api"><img src="https://img.shields.io/badge/bot api-v4.3-0688CB.svg" /></a>
</h6>

### [Migrating from Telepot »](https://docs.amanobot.ml/en/latest/migrating-from-telepot.html)
### [Introduction »](https://docs.amanobot.ml/en/latest)
### [Reference »](https://docs.amanobot.ml/en/latest/reference.html)
### [Examples »](https://github.com/AmanoTeam/amanobot/tree/master/examples)
### [Changelog »](https://github.com/AmanoTeam/amanobot/blob/master/CHANGELOG.md)
